# 1. Install Conda

Install on your machine following the [official instructions](https://docs.conda.io/projects/continuumio-conda/en/latest/user-guide/install/macos.html)

# 2. Create a conda enviroment

```sh
conda create -n dbrocket python=3.7
```

# 3. Activate the enviroment

```sh
conda activate dbrocket
```

From now on continue with the installation instructions from the readme.
